split

Function split 

pub fn split(
    data: &[u8],
    dtype: DataType,
    shape: &[usize],
    axis: i64,
    split: SplitSpec<'_>,
    keepdims: bool,
) -> SequenceResult<SequenceValue>
Split raw contiguous tensor bytes into a sequence of session tensors.

keepdims only affects SplitSpec::Each, as required by ONNX; an explicit split input always retains the split axis.