pub struct SequenceValue { /* private fields */ }Expand description
An ordered homogeneous list of immutable, shared tensors.
Implementations
Sourceimpl SequenceValue
impl SequenceValue
Sourcepub fn empty(elem_dtype: DataType) -> Self
pub fn empty(elem_dtype: DataType) -> Self
Construct an empty sequence with its declared tensor element dtype.
Sourcepub fn construct(items: Vec<SeqTensor>) -> SequenceResult<Self>
pub fn construct(items: Vec<SeqTensor>) -> SequenceResult<Self>
Construct a sequence without copying any element tensor storage.
Sourcepub fn insert(&self, value: SeqTensor, at: Option<i64>) -> SequenceResult<Self>
pub fn insert(&self, value: SeqTensor, at: Option<i64>) -> SequenceResult<Self>
Return a new sequence with value inserted at at.
None appends. Negative positions count from the end, and len is also
accepted as an explicit append position.
Sourcepub fn erase(&self, at: Option<i64>) -> SequenceResult<Self>
pub fn erase(&self, at: Option<i64>) -> SequenceResult<Self>
Return a new sequence with the selected element erased.
None erases the last element. Negative indices count from the end.
Sourcepub fn at(&self, index: i64) -> SequenceResult<SeqTensor>
pub fn at(&self, index: i64) -> SequenceResult<SeqTensor>
Return the selected shared tensor handle. Negative indices count from the end.
Sourcepub fn elem_dtype(&self) -> DataType
pub fn elem_dtype(&self) -> DataType
Declared homogeneous element dtype.